You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by rm...@apache.org on 2015/02/09 20:02:34 UTC

svn commit: r1658539 [2/3] - in /lucene/dev/trunk/solr: ./ contrib/dataimporthandler-extras/src/java/org/apache/solr/handler/dataimport/ contrib/dataimporthandler/src/java/org/apache/solr/handler/dataimport/ contrib/dataimporthandler/src/java/org/apach...

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/RequestHandlerBase.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/RequestHandlerBase.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/RequestHandlerBase.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/RequestHandlerBase.java Mon Feb  9 19:02:32 2015
@@ -62,7 +62,7 @@ public abstract class RequestHandlerBase
 
   /**
    * Initializes the {@link org.apache.solr.request.SolrRequestHandler} by creating three {@link org.apache.solr.common.params.SolrParams} named.
-   * <table border="1">
+   * <table border="1" summary="table of parameters">
    * <tr><th>Name</th><th>Description</th></tr>
    * <tr><td>defaults</td><td>Contains all of the named arguments contained within the list element named "defaults".</td></tr>
    * <tr><td>appends</td><td>Contains all of the named arguments contained within the list element named "appends".</td></tr>

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/SnapPuller.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/SnapPuller.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/SnapPuller.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/SnapPuller.java Mon Feb  9 19:02:32 2015
@@ -115,7 +115,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * <p/> Provides functionality of downloading changed index files as well as config files and a timer for scheduling fetches from the
+ * <p> Provides functionality of downloading changed index files as well as config files and a timer for scheduling fetches from the
  * master. </p>
  *
  *

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/SnapShooter.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/SnapShooter.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/SnapShooter.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/SnapShooter.java Mon Feb  9 19:02:32 2015
@@ -42,7 +42,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * <p/> Provides functionality equivalent to the snapshooter script </p>
+ * <p> Provides functionality equivalent to the snapshooter script </p>
  * This is no longer used in standard replication.
  *
  *

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/StandardRequestHandler.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/StandardRequestHandler.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/StandardRequestHandler.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/StandardRequestHandler.java Mon Feb  9 19:02:32 2015
@@ -29,7 +29,6 @@ import java.net.URL;
  * in the solrconfig as defaults, and may be overriden as request parameters.
  * (TODO: complete documentation of request parameters here, rather than only
  * on the wiki).
- * </p>
  *
  * <ul>
  * <li> highlight - Set to any value not .equal() to "false" to enable highlight

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/admin/CoreAdminHandler.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/admin/CoreAdminHandler.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/admin/CoreAdminHandler.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/admin/CoreAdminHandler.java Mon Feb  9 19:02:32 2015
@@ -482,7 +482,7 @@ public class CoreAdminHandler extends Re
 
   /**
    * Handle Custom Action.
-   * <p/>
+   * <p>
    * This method could be overridden by derived classes to handle custom actions. <br> By default - this method throws a
    * solr exception. Derived classes are free to write their derivation if necessary.
    */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/admin/ShowFileRequestHandler.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/admin/ShowFileRequestHandler.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/admin/ShowFileRequestHandler.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/admin/ShowFileRequestHandler.java Mon Feb  9 19:02:32 2015
@@ -57,7 +57,7 @@ import java.util.Set;
  * If you want to selectively restrict access some configuration files, you can list
  * these files in the {@link #HIDDEN} invariants.  For example to hide 
  * synonyms.txt and anotherfile.txt, you would register:
- * <p>
+ * <br>
  * <pre>
  * &lt;requestHandler name="/admin/file" class="org.apache.solr.handler.admin.ShowFileRequestHandler" &gt;
  *   &lt;lst name="defaults"&gt;
@@ -83,7 +83,7 @@ import java.util.Set;
  * set it directly using: {@link #USE_CONTENT_TYPE}.  For example, to get a plain text
  * version of schema.xml, try:
  * <pre>
- *   http://localhost:8983/solr/admin/file?file=schema.xml&contentType=text/plain
+ *   http://localhost:8983/solr/admin/file?file=schema.xml&amp;contentType=text/plain
  * </pre>
  *
  *

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/ExpandComponent.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/ExpandComponent.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/ExpandComponent.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/ExpandComponent.java Mon Feb  9 19:02:32 2015
@@ -92,17 +92,17 @@ import org.apache.solr.util.plugin.SolrC
 /**
  * The ExpandComponent is designed to work with the CollapsingPostFilter.
  * The CollapsingPostFilter collapses a result set on a field.
- * <p/>
+ * <p>
  * The ExpandComponent expands the collapsed groups for a single page.
- * <p/>
+ * <p>
  * http parameters:
- * <p/>
- * expand=true <br/>
- * expand.rows=5 <br/>
- * expand.sort=field asc|desc<br/>
- * expand.q=*:* (optional, overrides the main query)<br/>
- * expand.fq=type:child (optional, overrides the main filter queries)<br/>
- * expand.field=field (mandatory if the not used with the CollapsingQParserPlugin)<br/>
+ * <p>
+ * expand=true <br>
+ * expand.rows=5 <br>
+ * expand.sort=field asc|desc<br>
+ * expand.q=*:* (optional, overrides the main query)<br>
+ * expand.fq=type:child (optional, overrides the main filter queries)<br>
+ * expand.field=field (mandatory if the not used with the CollapsingQParserPlugin)<br>
  */
 public class ExpandComponent extends SearchComponent implements PluginInfoInitialized, SolrCoreAware {
   public static final String COMPONENT_NAME = "expand";

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/FieldFacetStats.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/FieldFacetStats.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/FieldFacetStats.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/FieldFacetStats.java Mon Feb  9 19:02:32 2015
@@ -39,7 +39,6 @@ import org.apache.solr.search.SolrIndexS
  * for facet values present in another field.
  * <p>
  * 9/10/2009 - Moved out of StatsComponent to allow open access to UnInvertedField
- * <p/>
  * @see org.apache.solr.handler.component.StatsComponent
  *
  */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/TermVectorComponent.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/TermVectorComponent.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/TermVectorComponent.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/handler/component/TermVectorComponent.java Mon Feb  9 19:02:32 2015
@@ -56,10 +56,10 @@ import org.apache.solr.util.plugin.SolrC
 
 /**
  * Return term vectors for the documents in a query result set.
- * <p/>
+ * <p>
  * Info available:
  * term, frequency, position, offset, IDF.
- * <p/>
+ * <p>
  * <b>Note</b> Returning IDF can be expensive.
  * 
  * <pre class="prettyprint">

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/highlight/WeightedFragListBuilder.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/highlight/WeightedFragListBuilder.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/highlight/WeightedFragListBuilder.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/highlight/WeightedFragListBuilder.java Mon Feb  9 19:02:32 2015
@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/internal/csv/writer/CSVConfig.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/internal/csv/writer/CSVConfig.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/internal/csv/writer/CSVConfig.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/internal/csv/writer/CSVConfig.java Mon Feb  9 19:02:32 2015
@@ -144,7 +144,7 @@ public class CSVConfig {
 
     /**
      * Set the fill pattern. Defaults to {@link #FILLNONE}
-     * <br/>Other options are : {@link #FILLLEFT} and {@link #FILLRIGHT}
+     * <br>Other options are : {@link #FILLLEFT} and {@link #FILLRIGHT}
      * @param fill the fill pattern.
      */
     public void setFill(int fill) {
@@ -258,7 +258,7 @@ public class CSVConfig {
     }
 
     /**
-     * Creates a config based on a stream. It tries to guess<br/>
+     * Creates a config based on a stream. It tries to guess<br>
      * NOTE : The stream will be closed.
      * @param inputStream the inputstream. 
      * @return the guessed config. 

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/EventAppender.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/EventAppender.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/EventAppender.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/EventAppender.java Mon Feb  9 19:02:32 2015
@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/Log4jInfo.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/Log4jInfo.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/Log4jInfo.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/Log4jInfo.java Mon Feb  9 19:02:32 2015
@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/Log4jWatcher.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/Log4jWatcher.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/Log4jWatcher.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/logging/log4j/Log4jWatcher.java Mon Feb  9 19:02:32 2015
@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/parser/SolrQueryParserBase.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/parser/SolrQueryParserBase.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/parser/SolrQueryParserBase.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/parser/SolrQueryParserBase.java Mon Feb  9 19:02:32 2015
@@ -271,7 +271,7 @@ public abstract class SolrQueryParserBas
    * Sets the boolean operator of the QueryParser.
    * In default mode (<code>OR_OPERATOR</code>) terms without any modifiers
    * are considered optional: for example <code>capital of Hungary</code> is equal to
-   * <code>capital OR of OR Hungary</code>.<br/>
+   * <code>capital OR of OR Hungary</code>.<br>
    * In <code>AND_OPERATOR</code> mode terms are considered to be in conjunction: the
    * above mentioned query is parsed as <code>capital AND of AND Hungary</code>
    */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/IntervalFacets.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/IntervalFacets.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/IntervalFacets.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/IntervalFacets.java Mon Feb  9 19:02:32 2015
@@ -53,7 +53,7 @@ import org.apache.solr.search.SyntaxErro
 
 /**
  * Computes interval facets for docvalues field (single or multivalued).
- * <p/>
+ * <p>
  * Given a set of intervals for a field and a DocSet, it calculates the number
  * of documents that match each of the intervals provided. The final count for
  * each interval should be exactly the same as the number of results of a range
@@ -61,12 +61,12 @@ import org.apache.solr.search.SyntaxErro
  * of {@code facet.query=field:[A TO B]} should be the same as the count of
  * {@code f.field.facet.interval.set=[A,B]}, however, this method will usually
  * be faster in cases where there are a larger number of intervals per field.
- * <p/>
+ * <p>
  * To use this class, create an instance using
  * {@link #IntervalFacets(SchemaField, SolrIndexSearcher, DocSet, String[], SolrParams)}
  * and then iterate the {@link FacetInterval} using {@link #iterator()}
- * <p/>
- * Intervals Format</br>
+ * <p>
+ * Intervals Format<br>
  * Intervals must begin with either '(' or '[', be followed by the start value,
  * then a comma ',', the end value, and finally ')' or ']'. For example:
  * <ul>
@@ -89,7 +89,7 @@ import org.apache.solr.search.SyntaxErro
  * As with facet.query, the key used to display the result can be set by using local params
  * syntax, for example:<p>
  * <code>{!key='First Half'}[0,5) </code>
- * <p/>
+ * <p>
  * To use this class:
  * <pre>
  * IntervalFacets intervalFacets = new IntervalFacets(schemaField, searcher, docs, intervalStrs, params);

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/SimpleFacets.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/SimpleFacets.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/SimpleFacets.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/SimpleFacets.java Mon Feb  9 19:02:32 2015
@@ -1245,7 +1245,7 @@ public class SimpleFacets {
   }
   
   /**
-   * A simple key=>val pair whose natural order is such that 
+   * A simple key=&gt;val pair whose natural order is such that 
    * <b>higher</b> vals come before lower vals.
    * In case of tie vals, then <b>lower</b> keys come before higher keys.
    */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/UnInvertedField.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/UnInvertedField.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/UnInvertedField.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/request/UnInvertedField.java Mon Feb  9 19:02:32 2015
@@ -462,7 +462,7 @@ public class UnInvertedField extends Doc
   /**
    * Collect statistics about the UninvertedField.  Code is very similar to {@link #getCounts(org.apache.solr.search.SolrIndexSearcher, org.apache.solr.search.DocSet, int, int, Integer, boolean, String, String)}
    * It can be used to calculate stats on multivalued fields.
-   * <p/>
+   * <p>
    * This method is mainly used by the {@link org.apache.solr.handler.component.StatsComponent}.
    *
    * @param searcher The Searcher to use to gather the statistics

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/response/SolrQueryResponse.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/response/SolrQueryResponse.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/response/SolrQueryResponse.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/response/SolrQueryResponse.java Mon Feb  9 19:02:32 2015
@@ -35,7 +35,7 @@ import org.apache.solr.search.SolrReturn
  * the response to a query request.
  *
  * <p>
- * <a name="returnable_data" /><b>Note On Returnable Data...</b><br/>
+ * <a name="returnable_data"></a><b>Note On Returnable Data...</b><br>
  * A <code>SolrQueryResponse</code> may contain the following types of
  * Objects generated by the <code>SolrRequestHandler</code> that processed
  * the request.

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/response/transform/DocTransformer.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/response/transform/DocTransformer.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/response/transform/DocTransformer.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/response/transform/DocTransformer.java Mon Feb  9 19:02:32 2015
@@ -26,7 +26,7 @@ import org.apache.solr.request.SolrQuery
  * A DocTransformer can add, remove or alter a Document before it is written out to the Response.  For instance, there are implementations
  * that can put explanations inline with a document, add constant values and mark items as being artificially boosted (see {@link org.apache.solr.handler.component.QueryElevationComponent})
  *
- * <p/>
+ * <p>
  * New instance for each request
  *
  * @see TransformerFactory

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/BaseSolrResource.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/BaseSolrResource.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/BaseSolrResource.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/BaseSolrResource.java Mon Feb  9 19:02:32 2015
@@ -73,7 +73,7 @@ public abstract class BaseSolrResource e
    * from the SolrRequestInfo thread local, then gets the SolrCore
    * and IndexSchema and sets up the response.
    * writer.
-   * <p/>
+   * <p>
    * If an error occurs during initialization, setExisting(false) is
    * called and an error status code and message is set; in this case,
    * Restlet will not continue servicing the request (by calling the

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/BaseFieldResource.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/BaseFieldResource.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/BaseFieldResource.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/BaseFieldResource.java Mon Feb  9 19:02:32 2015
@@ -56,7 +56,7 @@ abstract class BaseFieldResource extends
    * on this list.  The (Dynamic)FieldResource classes ignore this list, 
    * since the (dynamic) field is specified in the URL path, rather than
    * in a query parameter.
-   * <p/>
+   * <p>
    * Also pulls the "showDefaults" param from the request, for use by all
    * subclasses to include default values from the associated field type
    * in the response.  By default this param is off.

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/CopyFieldCollectionResource.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/CopyFieldCollectionResource.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/CopyFieldCollectionResource.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/CopyFieldCollectionResource.java Mon Feb  9 19:02:32 2015
@@ -43,7 +43,7 @@ import static org.apache.solr.common.Sol
 
 /**
  * This class responds to requests at /solr/(corename)/schema/copyfields
- * <p/>
+ * <p>
  *
  * To restrict the set of copyFields in the response, specify one or both
  * of the following as query parameters, with values as space and/or comma

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/DynamicFieldCollectionResource.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/DynamicFieldCollectionResource.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/DynamicFieldCollectionResource.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/DynamicFieldCollectionResource.java Mon Feb  9 19:02:32 2015
@@ -41,7 +41,7 @@ import java.util.Map;
 
 /**
  * This class responds to requests at /solr/(corename)/schema/dynamicfields
- * <p/>
+ * <p>
  * To restrict the set of dynamic fields in the response, specify a comma
  * and/or space separated list of dynamic field patterns in the "fl" query
  * parameter. 

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/FieldCollectionResource.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/FieldCollectionResource.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/FieldCollectionResource.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/FieldCollectionResource.java Mon Feb  9 19:02:32 2015
@@ -48,7 +48,7 @@ import java.util.TreeSet;
 
 /**
  * This class responds to requests at /solr/(corename)/schema/fields
- * <p/>
+ * <p>
  * Two query parameters are supported:
  * <ul>
  * <li>

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/FieldResource.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/FieldResource.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/FieldResource.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/rest/schema/FieldResource.java Mon Feb  9 19:02:32 2015
@@ -43,12 +43,12 @@ import java.util.Map;
 /**
  * This class responds to requests at /solr/(corename)/schema/fields/(fieldname)
  * where "fieldname" is the name of a field.
- * <p/>
+ * <p>
  * The GET method returns properties for the given fieldname.
  * The "includeDynamic" query parameter, if specified, will cause the
  * dynamic field matching the given fieldname to be returned if fieldname
  * is not explicitly declared in the schema.
- * <p/>
+ * <p>
  * The PUT method accepts field addition requests in JSON format.
  */
 public class FieldResource extends BaseFieldResource implements GETable, PUTable {

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/AbstractSpatialFieldType.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/AbstractSpatialFieldType.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/AbstractSpatialFieldType.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/AbstractSpatialFieldType.java Mon Feb  9 19:02:32 2015
@@ -242,7 +242,7 @@ public abstract class AbstractSpatialFie
    * Returns a String version of a shape to be used for the stored value. This method in Solr is only called if for some
    * reason a Shape object is passed to the field type (perhaps via a custom UpdateRequestProcessor),
    * *and* the field is marked as stored.  <em>The default implementation throws an exception.</em>
-   * <p/>
+   * <p>
    * Spatial4j 0.4 is probably the last release to support SpatialContext.toString(shape) but it's deprecated with no
    * planned replacement.  Shapes do have a toString() method but they are generally internal/diagnostic and not
    * standard WKT.
@@ -268,7 +268,7 @@ public abstract class AbstractSpatialFie
   //--------------------------------------------------------------
 
   /**
-   * Implemented for compatibility with geofilt & bbox query parsers:
+   * Implemented for compatibility with geofilt &amp; bbox query parsers:
    * {@link SpatialQueryable}.
    */
   @Override

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/CoordinateFieldType.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/CoordinateFieldType.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/CoordinateFieldType.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/CoordinateFieldType.java Mon Feb  9 19:02:32 2015
@@ -20,15 +20,15 @@ package org.apache.solr.schema;
 /**
  * A CoordinateFieldType is the base class for {@link org.apache.solr.schema.FieldType}s that have semantics
  * related to items in a coordinate system.
- * <br/>
+ * <br>
  * Implementations depend on a delegating work to a sub {@link org.apache.solr.schema.FieldType}, specified by
  * either the {@link #SUB_FIELD_SUFFIX} or the {@link #SUB_FIELD_TYPE} (the latter is used if both are defined.
- * <br/>
+ * <br>
  * Example:
  * <pre>&lt;fieldType name="xy" class="solr.PointType" dimension="2" subFieldType="double"/&gt;
  * </pre>
  * In theory, classes deriving from this should be able to do things like represent a point, a polygon, a line, etc.
- * <br/>
+ * <br>
  * NOTE: There can only be one sub Field Type.
  *
  */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/ExternalFileField.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/ExternalFileField.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/ExternalFileField.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/ExternalFileField.java Mon Feb  9 19:02:32 2015
@@ -30,7 +30,7 @@ import java.util.Map;
 
 /** Get values from an external file instead of the index.
  *
- * <p/><code>keyField</code> will normally be the unique key field, but it doesn't have to be.
+ * <p><code>keyField</code> will normally be the unique key field, but it doesn't have to be.
  * <ul><li> It's OK to have a keyField value that can't be found in the index</li>
  * <li>It's OK to have some documents without a keyField in the file (defVal is used as the default)</li>
  * <li>It's OK for a keyField value to point to multiple documents (no uniqueness requirement)</li>
@@ -40,19 +40,19 @@ import java.util.Map;
  * This parameter has never been implemented. As of Solr 3.6/4.0 it is optional and can be omitted.
  *
  * The format of the external file is simply newline separated keyFieldValue=floatValue.
- * <br/>Example:
- * <br/><code>doc33=1.414</code>
- * <br/><code>doc34=3.14159</code>
- * <br/><code>doc40=42</code>
+ * <br>Example:
+ * <br><code>doc33=1.414</code>
+ * <br><code>doc34=3.14159</code>
+ * <br><code>doc40=42</code>
  *
- * <p/>Solr looks for the external file in the index directory under the name of
+ * <p>Solr looks for the external file in the index directory under the name of
  * external_&lt;fieldname&gt; or external_&lt;fieldname&gt;.*
  *
- * <p/>If any files of the latter pattern appear, the last (after being sorted by name) will be used and previous versions will be deleted.
+ * <p>If any files of the latter pattern appear, the last (after being sorted by name) will be used and previous versions will be deleted.
  * This is to help support systems where one may not be able to overwrite a file (like Windows, if the file is in use).
- * <p/>If the external file has already been loaded, and it is changed, those changes will not be visible until a commit has been done.
- * <p/>The external file may be sorted or unsorted by the key field, but it will be substantially slower (untested) if it isn't sorted.
- * <p/>Fields of this type may currently only be used as a ValueSource in a FunctionQuery.
+ * <p>If the external file has already been loaded, and it is changed, those changes will not be visible until a commit has been done.
+ * <p>The external file may be sorted or unsorted by the key field, but it will be substantially slower (untested) if it isn't sorted.
+ * <p>Fields of this type may currently only be used as a ValueSource in a FunctionQuery.
  *
  * @see ExternalFileFieldReloader
  */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/ExternalFileFieldReloader.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/ExternalFileFieldReloader.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/ExternalFileFieldReloader.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/ExternalFileFieldReloader.java Mon Feb  9 19:02:32 2015
@@ -41,8 +41,8 @@ import java.util.List;
  * listeners in your solrconfig.xml:
  *
  * <pre>
- *   &lt;listener event="newSearcher" class="org.apache.solr.schema.ExternalFileFieldReloader"/>
- *   &lt;listener event="firstSearcher" class="org.apache.solr.schema.ExternalFileFieldReloader"/>
+ *   &lt;listener event="newSearcher" class="org.apache.solr.schema.ExternalFileFieldReloader"/&gt;
+ *   &lt;listener event="firstSearcher" class="org.apache.solr.schema.ExternalFileFieldReloader"/&gt;
  * </pre>
  *
  * The caches will be reloaded for all ExternalFileFields in your schema after

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/FieldType.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/FieldType.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/FieldType.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/FieldType.java Mon Feb  9 19:02:32 2015
@@ -231,7 +231,7 @@ public abstract class FieldType extends
    * (taken from toInternal()).   Having a different representation for
    * external, internal, and indexed would present quite a few problems
    * given the current Lucene architecture.  An analyzer for adding docs
-   * would need to translate internal->indexed while an analyzer for
+   * would need to translate internal-&gt;indexed while an analyzer for
    * querying would need to translate external-&gt;indexed.
    * </p>
    * <p>
@@ -434,7 +434,7 @@ public abstract class FieldType extends
   /**
    * Returns a Query instance for doing prefix searches on this field type.
    * Also, other QueryParser implementations may have different semantics.
-   * <p/>
+   * <p>
    * Sub-classes should override this method to provide their own range query implementation.
    *
    * @param parser       the {@link org.apache.solr.search.QParser} calling the method
@@ -676,7 +676,7 @@ public abstract class FieldType extends
    * currently passes part1 and part2 as null if they are '*' respectively. minInclusive and maxInclusive are both true
    * currently by SolrQueryParser but that may change in the future. Also, other QueryParser implementations may have
    * different semantics.
-   * <p/>
+   * <p>
    * Sub-classes should override this method to provide their own range query implementation. They should strive to
    * handle nulls in part1 and/or part2 as well as unequal minInclusive and maxInclusive parameters gracefully.
    *
@@ -792,7 +792,7 @@ public abstract class FieldType extends
   private static final String POSITION_INCREMENT_GAP = "positionIncrementGap";
 
   /**
-   * Get a map of property name -> value for this field type. 
+   * Get a map of property name -&gt; value for this field type. 
    * @param showDefaults if true, include default properties.
    */
   public SimpleOrderedMap<Object> getNamedPropertyValues(boolean showDefaults) {

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/IndexSchema.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/IndexSchema.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/IndexSchema.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/IndexSchema.java Mon Feb  9 19:02:32 2015
@@ -300,7 +300,7 @@ public class IndexSchema {
   
   /**
    * Name of the default search field specified in the schema file.
-   * <br/><b>Note:</b>Avoid calling this, try to use this method so that the 'df' param is consulted as an override:
+   * <br><b>Note:</b>Avoid calling this, try to use this method so that the 'df' param is consulted as an override:
    * {@link org.apache.solr.search.QueryParsing#getDefaultField(IndexSchema, String)}
    */
   public String getDefaultSearchFieldName() {
@@ -1356,7 +1356,7 @@ public class IndexSchema {
   }
 
   /**
-   * Get a map of property name -> value for the whole schema.
+   * Get a map of property name -&gt; value for the whole schema.
    */
   public SimpleOrderedMap<Object> getNamedPropertyValues() {
     SimpleOrderedMap<Object> topLevel = new SimpleOrderedMap<>();

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/RandomSortField.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/RandomSortField.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/RandomSortField.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/RandomSortField.java Mon Feb  9 19:02:32 2015
@@ -53,10 +53,10 @@ import org.apache.solr.search.QParser;
  * 
  * Examples of queries:
  * <ul>
- * <li>http://localhost:8983/solr/select/?q=*:*&fl=name&sort=random_1234%20desc</li>
- * <li>http://localhost:8983/solr/select/?q=*:*&fl=name&sort=random_2345%20desc</li>
- * <li>http://localhost:8983/solr/select/?q=*:*&fl=name&sort=random_ABDC%20desc</li>
- * <li>http://localhost:8983/solr/select/?q=*:*&fl=name&sort=random_21%20desc</li>
+ * <li>http://localhost:8983/solr/select/?q=*:*&amp;fl=name&amp;sort=random_1234%20desc</li>
+ * <li>http://localhost:8983/solr/select/?q=*:*&amp;fl=name&amp;sort=random_2345%20desc</li>
+ * <li>http://localhost:8983/solr/select/?q=*:*&amp;fl=name&amp;sort=random_ABDC%20desc</li>
+ * <li>http://localhost:8983/solr/select/?q=*:*&amp;fl=name&amp;sort=random_21%20desc</li>
  * </ul>
  * Note that multiple calls to the same URL will return the same sorting order.
  * 

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/SchemaField.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/SchemaField.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/SchemaField.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/SchemaField.java Mon Feb  9 19:02:32 2015
@@ -304,7 +304,7 @@ public final class SchemaField extends F
   }
 
   /**
-   * Get a map of property name -> value for this field.  If showDefaults is true,
+   * Get a map of property name -&gt; value for this field.  If showDefaults is true,
    * include default properties (those inherited from the declared property type and
    * not overridden in the field declaration).
    */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/TrieField.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/TrieField.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/TrieField.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/schema/TrieField.java Mon Feb  9 19:02:32 2015
@@ -62,13 +62,13 @@ import org.apache.solr.search.QParser;
  * {@link DoubleField}.
  * See {@link org.apache.lucene.search.NumericRangeQuery} for more details.
  * It supports integer, float, long, double and date types.
- * <p/>
+ * <p>
  * For each number being added to this field, multiple terms are generated as per the algorithm described in the above
  * link. The possible number of terms increases dramatically with lower precision steps. For
  * the fast range search to work, trie fields must be indexed.
- * <p/>
+ * <p>
  * Trie fields are sortable in numerical order and can be used in function queries.
- * <p/>
+ * <p>
  * Note that if you use a precisionStep of 32 for int/float and 64 for long/double/date, then multiple terms will not be
  * generated, range search will be no faster than any other number field, but sorting will still be possible.
  *

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/BitDocSet.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/BitDocSet.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/BitDocSet.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/BitDocSet.java Mon Feb  9 19:02:32 2015
@@ -60,7 +60,7 @@ public class BitDocSet extends DocSetBas
     this.size = size;
   }
 
-  /*** DocIterator using nextSetBit()
+  /* DocIterator using nextSetBit()
   public DocIterator iterator() {
     return new DocIterator() {
       int pos=bits.nextSetBit(0);
@@ -158,7 +158,7 @@ public class BitDocSet extends DocSetBas
   }
 
   /**
-   * Returns true of the doc exists in the set. Should only be called when doc <
+   * Returns true of the doc exists in the set. Should only be called when doc &lt;
    * {@link FixedBitSet#length()}.
    */
   @Override

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/CollapsingQParserPlugin.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/CollapsingQParserPlugin.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/CollapsingQParserPlugin.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/CollapsingQParserPlugin.java Mon Feb  9 19:02:32 2015
@@ -74,32 +74,32 @@ import org.apache.solr.schema.TrieLongFi
  This is a high performance alternative to standard Solr
  field collapsing (with ngroups) when the number of distinct groups
  in the result set is high.
- <p/>
+ <p>
  Sample syntax:
- <p/>
+ <p>
  Collapse based on the highest scoring document:
- <p/>
+ <p>
 
  fq=(!collapse field=field_name}
 
- <p/>
+ <p>
  Collapse based on the min value of a numeric field:
- <p/>
+ <p>
  fq={!collapse field=field_name min=field_name}
- <p/>
+ <p>
  Collapse based on the max value of a numeric field:
- <p/>
+ <p>
  fq={!collapse field=field_name max=field_name}
- <p/>
+ <p>
  Collapse with a null policy:
- <p/>
+ <p>
  fq={!collapse field=field_name nullPolicy=nullPolicy}
- <p/>
- There are three null policies: <br/>
- ignore : removes docs with a null value in the collapse field (default).<br/>
- expand : treats each doc with a null value in the collapse field as a separate group.<br/>
+ <p>
+ There are three null policies: <br>
+ ignore : removes docs with a null value in the collapse field (default).<br>
+ expand : treats each doc with a null value in the collapse field as a separate group.<br>
  collapse : collapses all docs with a null value into a single group using either highest score, or min/max.
- <p/>
+ <p>
  The CollapsingQParserPlugin fully supports the QueryElevationComponent
  **/
 

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/ComplexPhraseQParserPlugin.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/ComplexPhraseQParserPlugin.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/ComplexPhraseQParserPlugin.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/ComplexPhraseQParserPlugin.java Mon Feb  9 19:02:32 2015
@@ -29,7 +29,7 @@ import org.apache.solr.request.SolrQuery
 
 /**
  * Parse Solr's variant on the Lucene {@link org.apache.lucene.queryparser.complexPhrase.ComplexPhraseQueryParser} syntax.
- * <p/>
+ * <p>
  * Modified from {@link org.apache.solr.search.LuceneQParserPlugin} and {@link org.apache.solr.search.SurroundQParserPlugin}
  */
 public class ComplexPhraseQParserPlugin extends QParserPlugin {

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/DocList.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/DocList.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/DocList.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/DocList.java Mon Feb  9 19:02:32 2015
@@ -43,7 +43,7 @@ public interface DocList extends DocSet
    * Returns the total number of matches for the search
    * (as opposed to just the number collected according
    * to <code>offset()</code> and <code>size()</code>).
-   * Hence it's always true that matches() >= size()
+   * Hence it's always true that matches() &gt;= size()
    * @return number of matches for the search(query &amp; any filters)
    */
   public int matches();

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/ExtendedQuery.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/ExtendedQuery.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/ExtendedQuery.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/ExtendedQuery.java Mon Feb  9 19:02:32 2015
@@ -27,7 +27,7 @@ public interface ExtendedQuery {
   public void setCache(boolean cache);
 
   /** Returns the cost of this query, used to order checking of filters that are not cached.
-   * If getCache()==false && getCost()>=100 && this instanceof PostFilter, then
+   * If getCache()==false &amp;&amp; getCost()&gt;=100 &amp;&amp; this instanceof PostFilter, then
    * the PostFilter interface will be used for filtering.
    */
   public int getCost();

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/FastLRUCache.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/FastLRUCache.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/FastLRUCache.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/FastLRUCache.java Mon Feb  9 19:02:32 2015
@@ -30,10 +30,10 @@ import java.util.concurrent.TimeUnit;
 
 /**
  * SolrCache based on ConcurrentLRUCache implementation.
- * <p/>
+ * <p>
  * This implementation does not use a separate cleanup thread. Instead it uses the calling thread
  * itself to do the cleanup when the size of the cache exceeds certain limits.
- * <p/>
+ * <p>
  * Also see <a href="http://wiki.apache.org/solr/SolrCaching">SolrCaching</a>
  *
  *

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/Grouping.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/Grouping.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/Grouping.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/Grouping.java Mon Feb  9 19:02:32 2015
@@ -511,7 +511,7 @@ public class Grouping {
   /**
    * General group command. A group command is responsible for creating the first and second pass collectors.
    * A group command is also responsible for creating the response structure.
-   * <p/>
+   * <p>
    * Note: Maybe the creating the response structure should be done in something like a ReponseBuilder???
    * Warning NOT thread save!
    */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/LFUCache.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/LFUCache.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/LFUCache.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/LFUCache.java Mon Feb  9 19:02:32 2015
@@ -32,12 +32,12 @@ import java.util.concurrent.TimeUnit;
 
 /**
  * SolrCache based on ConcurrentLFUCache implementation.
- * <p/>
+ * <p>
  * This implementation does not use a separate cleanup thread. Instead it uses the calling thread
  * itself to do the cleanup when the size of the cache exceeds certain limits.
- * <p/>
+ * <p>
  * Also see <a href="http://wiki.apache.org/solr/SolrCaching">SolrCaching</a>
- * <p/>
+ * <p>
  * <b>This API is experimental and subject to change</b>
  *
  * @see org.apache.solr.util.ConcurrentLFUCache

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/MaxScoreQParser.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/MaxScoreQParser.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/MaxScoreQParser.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/MaxScoreQParser.java Mon Feb  9 19:02:32 2015
@@ -44,7 +44,7 @@ public class MaxScoreQParser extends Luc
    * delegates all SHOULD clauses to DisjunctionMaxQuery with
    * meaning only the clause with the max score will contribute
    * to the overall score, unless the tie parameter is specified.
-   * <br/>
+   * <br>
    * The max() is only calculated from the SHOULD clauses.
    * Any MUST clauses will be passed through as separate
    * BooleanClauses and thus always contribute to the score.

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/MaxScoreQParserPlugin.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/MaxScoreQParserPlugin.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/MaxScoreQParserPlugin.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/MaxScoreQParserPlugin.java Mon Feb  9 19:02:32 2015
@@ -23,7 +23,7 @@ import org.apache.solr.request.SolrQuery
  * Parses a query like Lucene query parser, but scoring with max score, not sum
  * <br>Accepts the "tie" request parameter as with dismax. 0.0=max, 1.0=sum
  * <br>All other parameters are as with Lucene parser
- * <br>Example: <code>q=foo {!maxscore v=$myq}&myq=A OR B OR C</code>
+ * <br>Example: <code>q=foo {!maxscore v=$myq}&amp;myq=A OR B OR C</code>
  */
 public class MaxScoreQParserPlugin extends LuceneQParserPlugin {
   public static final String NAME = "maxscore";

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/PostFilter.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/PostFilter.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/PostFilter.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/PostFilter.java Mon Feb  9 19:02:32 2015
@@ -22,7 +22,7 @@ import org.apache.lucene.search.IndexSea
 /** The PostFilter interface provides a mechanism to further filter documents
  * after they have already gone through the main query and other filters.
  * This is appropriate for filters with a very high cost.
- * <p/>
+ * <p>
  * The filtering mechanism used is a {@link DelegatingCollector}
  * that allows the filter to not call the delegate for certain documents,
  * thus effectively filtering them out.  This also avoids the normal

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/QueryParsing.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/QueryParsing.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/QueryParsing.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/QueryParsing.java Mon Feb  9 19:02:32 2015
@@ -569,7 +569,6 @@ public class QueryParsing {
   /**
    * Formats a Query for debugging, using the IndexSchema to make
    * complex field types readable.
-   * <p/>
    * <p>
    * The benefit of using this method instead of calling
    * <code>Query.toString</code> directly is that it knows about the data

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/Sorting.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/Sorting.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/Sorting.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/Sorting.java Mon Feb  9 19:02:32 2015
@@ -20,7 +20,7 @@ package org.apache.solr.search;
 import org.apache.lucene.search.*;
 
 /**
- * Extra lucene sorting utilities & convenience methods
+ * Extra lucene sorting utilities &amp; convenience methods
  *
  *
  *

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/SpatialFilterQParserPlugin.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/SpatialFilterQParserPlugin.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/SpatialFilterQParserPlugin.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/SpatialFilterQParserPlugin.java Mon Feb  9 19:02:32 2015
@@ -22,15 +22,14 @@ import org.apache.solr.request.SolrQuery
 
 /**
  * Creates a spatial Filter based on the type of spatial point used.
- * <p/>
+ * <p>
  * The field must implement {@link org.apache.solr.schema.SpatialQueryable}
- * <p/>
+ * <p>
  * All units are in Kilometers
- * <p/>
- * <p/>
+ * <p>
  * Syntax:
  * <pre>{!geofilt sfield=&lt;location_field&gt; pt=&lt;lat,lon&gt; d=&lt;distance&gt;}</pre>
- * <p/>
+ * <p>
  * Parameters:
  * <ul>
  * <li>sfield - The field to filter on. Required.</li>
@@ -38,13 +37,12 @@ import org.apache.solr.request.SolrQuery
  * <li>d - The distance in km.  Required.</li>
  * </ul>
  * The distance measure used currently depends on the FieldType.  LatLonType defaults to using haversine, PointType defaults to Euclidean (2-norm).
- *
- * <p/>
+ * <p>
  * Examples:
  * <pre>fq={!geofilt sfield=store pt=10.312,-20.556 d=3.5}</pre>
- * <pre>fq={!geofilt sfield=store}&pt=10.312,-20&d=3.5</pre>
- * <pre>fq={!geofilt}&sfield=store&pt=10.312,-20&d=3.5</pre>
- * <p/>
+ * <pre>fq={!geofilt sfield=store}&amp;pt=10.312,-20&amp;d=3.5</pre>
+ * <pre>fq={!geofilt}&amp;sfield=store&amp;pt=10.312,-20&amp;d=3.5</pre>
+ * <p>
  * Note: The geofilt for LatLonType is capable of also producing scores equal to the computed distance from the point
  * to the field, making it useful as a component of the main query or a boosting query.
  */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/GeohashFunction.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/GeohashFunction.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/GeohashFunction.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/GeohashFunction.java Mon Feb  9 19:02:32 2015
@@ -27,10 +27,10 @@ import java.io.IOException;
 
 /**
  * Takes in a latitude and longitude ValueSource and produces a GeoHash.
- * <p/>
+ * <p>
  * Ex: geohash(lat, lon)
  *
- * <p/>
+ * <p>
  * Note, there is no reciprocal function for this.
  **/
 public class GeohashFunction extends ValueSource {

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/GeohashHaversineFunction.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/GeohashHaversineFunction.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/GeohashHaversineFunction.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/GeohashHaversineFunction.java Mon Feb  9 19:02:32 2015
@@ -35,9 +35,9 @@ import java.util.Map;
 /**
  *  Calculate the Haversine distance between two geo hash codes.
  *
- * <p/>
+ * <p>
  * Ex: ghhsin(ValueSource, ValueSource, radius)
- * <p/>
+ * <p>
  *
  * @see org.apache.solr.search.function.distance.HaversineFunction for more details on the implementation
  *

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/HaversineFunction.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/HaversineFunction.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/HaversineFunction.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/HaversineFunction.java Mon Feb  9 19:02:32 2015
@@ -32,9 +32,9 @@ import java.util.Map;
 /**
  * Calculate the Haversine formula (distance) between any two points on a sphere
  * Takes in four value sources: (latA, lonA); (latB, lonB).
- * <p/>
+ * <p>
  * Assumes the value sources are in radians unless
- * <p/>
+ * <p>
  * See http://en.wikipedia.org/wiki/Great-circle_distance and
  * http://en.wikipedia.org/wiki/Haversine_formula for the actual formula and
  * also http://www.movable-type.co.uk/scripts/latlong.html

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/VectorDistanceFunction.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/VectorDistanceFunction.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/VectorDistanceFunction.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/function/distance/VectorDistanceFunction.java Mon Feb  9 19:02:32 2015
@@ -30,7 +30,7 @@ import java.util.Map;
 
 /**
  * Calculate the p-norm for a Vector.  See http://en.wikipedia.org/wiki/Lp_space
- * <p/>
+ * <p>
  * Common cases:
  * <ul>
  * <li>0 = Sparseness calculation</li>
@@ -79,7 +79,7 @@ public class VectorDistanceFunction exte
 
   /**
    * Calculate the p-norm (i.e. length) between two vectors.
-   * <p/>
+   * <p>
    * See <a href="http://en.wikipedia.org/wiki/Lp_space">Lp space</a>
    *
    * @param vec1  The first vector

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/similarities/DFRSimilarityFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/similarities/DFRSimilarityFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/similarities/DFRSimilarityFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/search/similarities/DFRSimilarityFactory.java Mon Feb  9 19:02:32 2015
@@ -99,7 +99,6 @@ import org.apache.solr.schema.Similarity
  *        </ul>
  * </ol>
  * <p>
- * <p>
  * Optional settings:
  * <ul>
  *   <li>discountOverlaps (bool): Sets

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/servlet/DirectSolrConnection.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/servlet/DirectSolrConnection.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/servlet/DirectSolrConnection.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/servlet/DirectSolrConnection.java Mon Feb  9 19:02:32 2015
@@ -69,7 +69,7 @@ public class DirectSolrConnection
   /**
    * For example:
    * 
-   * String json = solr.request( "/select?qt=dismax&wt=json&q=...", null );
+   * String json = solr.request( "/select?qt=dismax&amp;wt=json&amp;q=...", null );
    * String xml = solr.request( "/update", "&lt;add&gt;&lt;doc&gt;&lt;field ..." );
    */
   public String request( String pathAndParams, String body ) throws Exception

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/servlet/ResponseUtils.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/servlet/ResponseUtils.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/servlet/ResponseUtils.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/servlet/ResponseUtils.java Mon Feb  9 19:02:32 2015
@@ -31,10 +31,10 @@ public class ResponseUtils {
 
   /**
    * Adds the given Throwable's message to the given NamedList.
-   * <p/>
+   * <p>
    * If the response code is not a regular code, the Throwable's
    * stack trace is both logged and added to the given NamedList.
-   * <p/>
+   * <p>
    * Status codes less than 100 are adjusted to be 500.
    */
   public static int getErrorInfo(Throwable ex, NamedList info, Logger log) {

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/spelling/SolrSpellChecker.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/spelling/SolrSpellChecker.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/spelling/SolrSpellChecker.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/spelling/SolrSpellChecker.java Mon Feb  9 19:02:32 2015
@@ -187,7 +187,6 @@ public abstract class SolrSpellChecker {
   /**
    * Get suggestions for the given query.  Tokenizes the query using a field appropriate Analyzer.
    * The {@link SpellingResult#getSuggestions()} suggestions must be ordered by best suggestion first.
-   * <p/>
    *
    * @param options The {@link SpellingOptions} to use
    * @return The {@link SpellingResult} suggestions

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/spelling/suggest/SuggesterParams.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/spelling/suggest/SuggesterParams.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/spelling/suggest/SuggesterParams.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/spelling/suggest/SuggesterParams.java Mon Feb  9 19:02:32 2015
@@ -28,7 +28,7 @@ public interface SuggesterParams {
 
   /**
    * The count of suggestions to return for each query term not in the index and/or dictionary.
-   * <p/>
+   * <p>
    * If this parameter is absent in the request then only one suggestion is
    * returned. If it is more than one then a maximum of given suggestions are
    * returned for each token in the query.
@@ -37,7 +37,7 @@ public interface SuggesterParams {
   
   /**
    * Use the value for this parameter as the query to spell check.
-   * <p/>
+   * <p>
    * This parameter is <b>optional</b>. If absent, then the q parameter is
    * used.
    */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/CommitUpdateCommand.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/CommitUpdateCommand.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/CommitUpdateCommand.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/CommitUpdateCommand.java Mon Feb  9 19:02:32 2015
@@ -31,7 +31,7 @@ public class CommitUpdateCommand extends
   public boolean prepareCommit = false;
 
   /**
-   * During optimize, optimize down to <= this many segments.  Must be >= 1
+   * During optimize, optimize down to &lt;= this many segments.  Must be &gt;= 1
    *
    * @see org.apache.lucene.index.IndexWriter#forceMerge(int)
    */

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/DirectUpdateHandler2.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/DirectUpdateHandler2.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/DirectUpdateHandler2.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/DirectUpdateHandler2.java Mon Feb  9 19:02:32 2015
@@ -15,9 +15,6 @@
  * limitations under the License.
  */
 
-/**
- */
-
 package org.apache.solr.update;
 
 import org.apache.lucene.document.Document;

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/DocumentBuilder.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/DocumentBuilder.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/DocumentBuilder.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/DocumentBuilder.java Mon Feb  9 19:02:32 2015
@@ -64,7 +64,7 @@ public class DocumentBuilder {
    * Convert a SolrInputDocument to a lucene Document.
    * 
    * This function should go elsewhere.  This builds the Document without an
-   * extra Map<> checking for multiple values.  For more discussion, see:
+   * extra Map&lt;&gt; checking for multiple values.  For more discussion, see:
    * http://www.nabble.com/Re%3A-svn-commit%3A-r547493---in--lucene-solr-trunk%3A-.--src-java-org-apache-solr-common--src-java-org-apache-solr-schema--src-java-org-apache-solr-update--src-test-org-apache-solr-common--tf3931539.html
    * 
    * TODO: /!\ NOTE /!\ This semantics of this function are still in flux.  

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/DefaultValueUpdateProcessorFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/DefaultValueUpdateProcessorFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/DefaultValueUpdateProcessorFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/DefaultValueUpdateProcessorFactory.java Mon Feb  9 19:02:32 2015
@@ -38,7 +38,7 @@ import org.apache.solr.update.AddUpdateC
  * in the <code>price</code> and/or <code>type</code> fields, it will be given 
  * default values of <code>0.0</code> and/or <code>unknown</code> 
  * (respectively).
- * <p>
+ * <br>
  *
  * <pre class="prettyprint">
  * &lt;processor class="solr.DefaultValueUpdateProcessorFactory"&gt;

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/MaxFieldValueUpdateProcessorFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/MaxFieldValueUpdateProcessorFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/MaxFieldValueUpdateProcessorFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/MaxFieldValueUpdateProcessorFactory.java Mon Feb  9 19:02:32 2015
@@ -41,7 +41,7 @@ import java.util.Iterator;
  * values (ie: <code>64, 128, 1024</code>) in the field 
  * <code>largestFileSize</code> then only the biggest value 
  * (ie: <code>1024</code>) will be kept in that field.
- * <p>
+ * <br>
  *
  * <pre class="prettyprint">
  *  &lt;processor class="solr.MaxFieldValueUpdateProcessorFactory"&gt;

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/MinFieldValueUpdateProcessorFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/MinFieldValueUpdateProcessorFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/MinFieldValueUpdateProcessorFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/MinFieldValueUpdateProcessorFactory.java Mon Feb  9 19:02:32 2015
@@ -41,7 +41,7 @@ import java.util.Iterator;
  * values (ie: <code>64, 128, 1024</code>) in the field 
  * <code>smallestFileSize</code> then only the smallest value 
  * (ie: <code>64</code>) will be kept in that field.
- * <p>
+ * <br>
  *
  * <pre class="prettyprint">
  *  &lt;processor class="solr.MinFieldValueUpdateProcessorFactory"&gt;

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/ParseBooleanFieldUpdateProcessorFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/ParseBooleanFieldUpdateProcessorFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/ParseBooleanFieldUpdateProcessorFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/ParseBooleanFieldUpdateProcessorFactory.java Mon Feb  9 19:02:32 2015
@@ -64,7 +64,7 @@ import java.util.Set;
  *   &lt;arr name="falseValue"&gt;
  *     &lt;str&gt;False&lt;/str&gt;
  *     &lt;str&gt;No&lt;/str&gt;
- *   &lt:/arr&gt;
+ *   &lt;/arr&gt;
  * &lt;/processor&gt;</pre>
  */
 public class ParseBooleanFieldUpdateProcessorFactory extends FieldMutatingUpdateProcessorFactory {

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/ScriptEngineCustomizer.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/ScriptEngineCustomizer.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/ScriptEngineCustomizer.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/ScriptEngineCustomizer.java Mon Feb  9 19:02:32 2015
@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/StatelessScriptUpdateProcessorFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/StatelessScriptUpdateProcessorFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/StatelessScriptUpdateProcessorFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/StatelessScriptUpdateProcessorFactory.java Mon Feb  9 19:02:32 2015
@@ -90,7 +90,6 @@ import org.slf4j.LoggerFactory;
  *  <li>logger - A {@link Logger} that can be used for logging purposes in the script</li>
  *  <li>params - The "params" init argument in the factory configuration (if any)</li>
  * </ul>
- * </p>
  * <p>
  * Internally this update processor uses JDK 6 scripting engine support, 
  * and any {@link Invocable} implementations of <code>ScriptEngine</code> 

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/TimestampUpdateProcessorFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/TimestampUpdateProcessorFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/TimestampUpdateProcessorFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/TimestampUpdateProcessorFactory.java Mon Feb  9 19:02:32 2015
@@ -42,7 +42,7 @@ import org.apache.solr.common.params.Com
  * In the example configuration below, if a document does not contain a value 
  * in the <code>timestamp</code> field, a new <code>Date</code> will be 
  * generated and added as the value of that field.
- * <p>
+ * <br>
  *
  * <pre class="prettyprint">
  * &lt;processor class="solr.TimestampUpdateProcessorFactory"&gt;

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/UUIDUpdateProcessorFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/UUIDUpdateProcessorFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/UUIDUpdateProcessorFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/update/processor/UUIDUpdateProcessorFactory.java Mon Feb  9 19:02:32 2015
@@ -40,7 +40,7 @@ import org.apache.solr.schema.SchemaFiel
  * In the example configuration below, if a document does not contain a value
  * in the <code>id</code> field, a new <code>UUID</code> will be generated
  * and added as the value of that field.
- * <p>
+ * <br>
  *
  * <pre class="prettyprint">
  * &lt;processor class="solr.UUIDUpdateProcessorFactory"&gt;
@@ -54,7 +54,6 @@ import org.apache.solr.schema.SchemaFiel
  * is used as field and a new <code>UUID</code> will be generated
  * and added as the value of that field. The field type of the uniqueKeyField
  * must be anything which accepts a string or UUID value.
- * <p>
  * @see UUID
  */
 public class UUIDUpdateProcessorFactory extends UpdateRequestProcessorFactory {

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/ConcurrentLFUCache.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/ConcurrentLFUCache.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/ConcurrentLFUCache.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/ConcurrentLFUCache.java Mon Feb  9 19:02:32 2015
@@ -31,11 +31,11 @@ import java.util.concurrent.locks.Reentr
 
 /**
  * A LFU cache implementation based upon ConcurrentHashMap.
- * <p/>
+ * <p>
  * This is not a terribly efficient implementation.  The tricks used in the
  * LRU version were not directly usable, perhaps it might be possible to
  * rewrite them with LFU in mind.
- * <p/>
+ * <p>
  * <b>This API is experimental and subject to change</b>
  *
  * @since solr 1.6
@@ -215,7 +215,7 @@ public class ConcurrentLFUCache<K, V> {
 
   /**
    * Returns 'n' number of least used entries present in this cache.
-   * <p/>
+   * <p>
    * This uses a TreeSet to collect the 'n' least used items ordered by ascending hitcount
    * and returns a LinkedHashMap containing 'n' or less than 'n' entries.
    *
@@ -259,7 +259,7 @@ public class ConcurrentLFUCache<K, V> {
 
   /**
    * Returns 'n' number of most used entries present in this cache.
-   * <p/>
+   * <p>
    * This uses a TreeSet to collect the 'n' most used items ordered by descending hitcount
    * and returns a LinkedHashMap containing 'n' or less than 'n' entries.
    *

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/ConcurrentLRUCache.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/ConcurrentLRUCache.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/ConcurrentLRUCache.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/ConcurrentLRUCache.java Mon Feb  9 19:02:32 2015
@@ -34,7 +34,7 @@ import java.lang.ref.WeakReference;
 /**
  * A LRU cache implementation based upon ConcurrentHashMap and other techniques to reduce
  * contention and synchronization overhead to utilize multiple CPU cores more effectively.
- * <p/>
+ * <p>
  * Note that the implementation does not follow a true LRU (least-recently-used) eviction
  * strategy. Instead it strives to remove least recently used items but when the initial
  * cleanup does not remove enough items to reach the 'acceptableWaterMark' limit, it can

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/LongPriorityQueue.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/LongPriorityQueue.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/LongPriorityQueue.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/LongPriorityQueue.java Mon Feb  9 19:02:32 2015
@@ -149,7 +149,7 @@ public class LongPriorityQueue {
   }
 
   /** Removes and returns the least element of the PriorityQueue in log(size)
-    time.  Only valid if size() > 0.
+    time.  Only valid if size() &gt; 0.
    */
   public long pop() {
     long result = heap[1];            // save first value

Modified: lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/SimplePostTool.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/SimplePostTool.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/SimplePostTool.java (original)
+++ lucene/dev/trunk/solr/core/src/java/org/apache/solr/util/SimplePostTool.java Mon Feb  9 19:02:32 2015
@@ -564,7 +564,7 @@ public class SimplePostTool {
 
   /**
    * A very simple crawler, pulling URLs to fetch from a backlog and then
-   * recurses N levels deep if recursive>0. Links are parsed from HTML
+   * recurses N levels deep if recursive&gt;0. Links are parsed from HTML
    * through first getting an XHTML version using SolrCell with extractOnly,
    * and followed if they are local. The crawler pauses for a default delay
    * of 10 seconds between each fetch, this can be configured in the delay
@@ -744,7 +744,7 @@ public class SimplePostTool {
   /**
    * Appends a URL query parameter to a URL 
    * @param url the original URL
-   * @param param the parameter(s) to append, separated by "&"
+   * @param param the parameter(s) to append, separated by "&amp;"
    * @return the string version of the resulting URL
    */
   public static String appendParam(String url, String param) {

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/BasicFunctionalityTest.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/BasicFunctionalityTest.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/BasicFunctionalityTest.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/BasicFunctionalityTest.java Mon Feb  9 19:02:32 2015
@@ -77,7 +77,7 @@ public class BasicFunctionalityTest exte
   }
   // tests the performance of dynamic field creation and
   // field property testing.
-  /***
+  /*
   public void testFieldPerf() {
     IndexSchema schema = h.getCore().getSchema();
     SchemaField[] fields = schema.getDynamicFieldPrototypes();

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/CursorPagingTest.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/CursorPagingTest.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/analysis/TestCharFilters.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/analysis/TestCharFilters.java Mon Feb  9 19:02:32 2015
@@ -39,7 +39,7 @@ public class TestCharFilters extends Sol
   
   /**
    * Test query analysis: at querytime MockCharFilter will
-   * double the 'a', so ab -> aab, and aba -> aabaa
+   * double the 'a', so ab -&gt; aab, and aba -&gt; aabaa
    * 
    * We run the test twice to make sure reuse is working
    */
@@ -58,7 +58,7 @@ public class TestCharFilters extends Sol
   
   /**
    * Test index analysis: at indextime MockCharFilter will
-   * double the 'a', so ab -> aab, and aba -> aabaa
+   * double the 'a', so ab -&gt; aab, and aba -&gt; aabaa
    * 
    * We run the test twice to make sure reuse is working
    */

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/analysis/TestWordDelimiterFilterFactory.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/analysis/TestWordDelimiterFilterFactory.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/analysis/TestWordDelimiterFilterFactory.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/analysis/TestWordDelimiterFilterFactory.java Mon Feb  9 19:02:32 2015
@@ -126,7 +126,7 @@ public class TestWordDelimiterFilterFact
     clearIndex();
   }
 
-  /***
+  /*
   public void testPerformance() throws IOException {
     String s = "now is the time-for all good men to come to-the aid of their country.";
     Token tok = new Token();
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/CursorPagingTest.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/CursorPagingTest.java Mon Feb  9 19:02:32 2015
@@ -22,17 +22,19 @@ import org.apache.lucene.util.SentinelIn
 import org.apache.lucene.util.mutable.MutableValueInt;
 import org.apache.solr.core.SolrInfoMBean;
 import org.apache.solr.common.SolrInputDocument;
+import org.apache.solr.common.params.CursorMarkParams;
 import org.apache.solr.common.params.SolrParams;
 import org.apache.solr.common.params.CommonParams;
 import org.apache.solr.common.params.GroupParams;
+
 import static org.apache.solr.common.params.CursorMarkParams.CURSOR_MARK_PARAM;
 import static org.apache.solr.common.params.CursorMarkParams.CURSOR_MARK_NEXT;
 import static org.apache.solr.common.params.CursorMarkParams.CURSOR_MARK_START;
+
 import org.apache.solr.common.SolrException;
 import org.apache.solr.common.SolrException.ErrorCode;
 import org.apache.solr.request.SolrQueryRequest;
 import org.apache.solr.search.CursorMark; //jdoc
-
 import org.noggit.ObjectBuilder;
 
 import java.nio.ByteBuffer;
@@ -49,7 +51,7 @@ import org.junit.BeforeClass;
 import org.junit.After;
 
 /**
  * Tests of deep paging using {@link CursorMark} and {@link #CURSOR_MARK_PARAM}.
  */
 public class CursorPagingTest extends SolrTestCaseJ4 {
 
@@ -651,8 +653,8 @@ public class CursorPagingTest extends So
   }
 
   /**
    * Given a set of params, executes a cursor query using {@link #CURSOR_MARK_START}
    * and then continuously walks the results using {@link #CURSOR_MARK_START} as long
    * as a non-0 number of docs ar returned.  This method records the the set of all id's
    * (must be positive ints) encountered and throws an assertion failure if any id is
    * encountered more than once, or if the set grows above maxSize
@@ -733,8 +735,8 @@ public class CursorPagingTest extends So
   }
 
   /**
    * Given a set of params, executes a cursor query using {@link #CURSOR_MARK_START}
    * and then continuously walks the results using {@link #CURSOR_MARK_START} as long
    * as a non-0 number of docs ar returned.  This method records the the set of all id's
    * (must be positive ints) encountered and throws an assertion failure if any id is
    * encountered more than once, or if the set grows above maxSize.
@@ -817,7 +819,7 @@ public class CursorPagingTest extends So
 
   /**
    * Asserts that the query matches the specified JSON patterns and then returns the
    * {@link #CURSOR_MARK_NEXT} value from the response
    *
    * @see #assertJQ
    */
@@ -49,7 +51,7 @@ import org.junit.BeforeClass;
 
 /**
- * Tests of deep paging using {@link CursorMark} and {@link #CURSOR_MARK_PARAM}.
+ * Tests of deep paging using {@link CursorMark} and {@link CursorMarkParams#CURSOR_MARK_PARAM}.
  */
 public class CursorPagingTest extends SolrTestCaseJ4 {
@@ -651,8 +653,8 @@ public class CursorPagingTest extends So
 
   /**
-   * Given a set of params, executes a cursor query using {@link #CURSOR_MARK_START}
-   * and then continuously walks the results using {@link #CURSOR_MARK_START} as long
+   * Given a set of params, executes a cursor query using {@link CursorMarkParams#CURSOR_MARK_START}
+   * and then continuously walks the results using {@link CursorMarkParams#CURSOR_MARK_START} as long
    * as a non-0 number of docs ar returned.  This method records the the set of all id's
    * (must be positive ints) encountered and throws an assertion failure if any id is
@@ -733,8 +735,8 @@ public class CursorPagingTest extends So
 
   /**
-   * Given a set of params, executes a cursor query using {@link #CURSOR_MARK_START}
-   * and then continuously walks the results using {@link #CURSOR_MARK_START} as long
+   * Given a set of params, executes a cursor query using {@link CursorMarkParams#CURSOR_MARK_START}
+   * and then continuously walks the results using {@link CursorMarkParams#CURSOR_MARK_START} as long
    * as a non-0 number of docs ar returned.  This method records the the set of all id's
    * (must be positive ints) encountered and throws an assertion failure if any id is
@@ -817,7 +819,7 @@ public class CursorPagingTest extends So
   /**
    * Asserts that the query matches the specified JSON patterns and then returns the
-   * {@link #CURSOR_MARK_NEXT} value from the response
+   * {@link CursorMarkParams#CURSOR_MARK_NEXT} value from the response
    *
    * @see #assertJQ

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/analysis/TestCharFilters.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/analysis/TestCharFilters.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================